@@ -6,6 +6,7 @@ use strict;
 use base 'SIAM::Object';
 
 use SIAM::ServiceDataElement;
+use SIAM::Device;
 
 =head1 NAME
 
@@ -33,10 +34,11 @@ sub get_data_elements
 # mandatory attributes
 
 my $mandatory_attributes =
-    [ 'svcunit.name',
-      'svcunit.type',
-      'svcunit.inventory_id',
-      'svcunit.location' ];
+    [ 'siam.svcunit.name',
+      'siam.svcunit.type',
+      'siam.svcunit.inventory_id',
+      'siam.svcunit.device_id',
+      'siam.svcunit.location' ];
 
 sub _mandatory_attributes
 {
